#include <iostream> 
#include "stdio.h"
#include "math.h"
#include "TROOT.h"
#include "TSystem.h"
#include "TDatime.h"
#include "TRint.h"
#include "ScanRootGui.h"
#include "ScanRootExe.hh"
#include "TStyle.h"
#include "TString.h"
#include "TBrowser.h"
#include "log.hh"
#include "version.h"

#define   MAXOUT 4

using namespace std;

extern void InitGui();
VoidFuncPtr_t initfuncs[] = {InitGui,0};
TROOT root("SCANROOT","SCANROOT",initfuncs);

ScanRootGui *SCAN = 0;

void banner()
{
  log(10,"  *******************************************");
  log(10,"  **                                       **");
  log(10,"  **         S c a n R o o t  v %2d.%02d      **",SCANROOT_VERSION,SCANROOT_REVISION);
  log(10,"  **                                       **");
  log(10,"  **     (c) 2003-%4d A. A. P. Suaide     **",PELLIB_YEAR);  
  log(10,"  **                                       **");
  log(10,"  *******************************************");
  log(10,"");
  log(10,"Running ScanRoot. type scanroot -help for options ");
  log(10,"type menu() to open the ScanRoot Menu ");  
  log(10,"");
  log("ScanRoot has started");
  log(10,"");
}
int main(int argc, char** argv)
{     
  bool debug = false;
  bool help = false;
  bool t = false;
  bool f = false;
  bool nogui = false;
  if(argc>1) for(int i=1;i<argc;i++) 
  {
    bool id = false;
    if(!strcmp(argv[i],"-debug")) { debug = true; id = true;}
    if(!strcmp(argv[i],"-help"))  { help = true;  id = true;}
    if(!strcmp(argv[i],"-nogui")) { nogui = true; id = true;}
    if(!strcmp(argv[i],"-d"))     { debug = true; id = true;}
    if(!strcmp(argv[i],"-h"))     { help = true;  id = true;}
    if(!strcmp(argv[i],"-n"))     { nogui = true; id = true;}
    
    TString file = argv[i];
    if(file.EndsWith(".root")) { f = true; id = true;}
		
    if(!id)
    {
      cout <<endl<<"ScanRoot::error()"<<endl;
      cout <<"Option "<<argv[i]<<" is not valid! Use scanroot -h for help"<<endl;
      return 0;
    }
		
  }
  if(help)
  {   
    char line[100];
    sprintf(line,"ScanRoot version %2d.%02d (c) 2003-%4d by A. A. P. Suaide",SCANROOT_VERSION,SCANROOT_REVISION,PELLIB_YEAR);
    cout <<line<<endl;
    cout <<"usage: spmroot [-h|help] [-d|debug] [-t|tools] [file1] [file2] ... "<<endl;
    cout <<"-h or -help       displays this message"<<endl;
    cout <<"-d or -debug      turns on debug mode and display event by event information"<<endl;
    cout <<"-n or -nogui      does not open the ScanRoot Menu"<<endl;
    cout <<"file1.root, file2.root,...  opens root files and display the browser"<<endl;
    return 0;
  }  
  appendLog("ScanRoot.log");
  banner();
  
  TRint r((const char*)"RU",&argc,argv,0,0,kTRUE);  
  gStyle->SetPalette(1,0);
  gStyle->SetOptLogz(1);  
  r.SetPrompt("ScanRoot [%d]> ");  
  SCAN = new ScanRootGui(debug); 

  gROOT->ProcessLine(Form("ScanRootGui *gSCAN = (ScanRootGui*) 0x%x",SCAN));

  if(!nogui) SCAN->makeGUI(); 
  if(f) new TBrowser();
  r.Run();
  closeLog();
	cout <<endl;
  return 1;
}
void debug(bool d)          
{ 
  SCAN->debugGUI(d);
}
void openInput(char* file)  
{ 
  SCAN->getIO()->closeInput(); 
  SCAN->getIO()->openInput(file);
}
void closeInput()           
{ 
  SCAN->getIO()->closeInput();
}
void rewind()           
{ 
  SCAN->getIO()->rewind();
}
void openOutput(char* file,int out)  
{ 
  if(out<0 || out>=MAXOUT) return;
  SCAN->getIO()->closeOutput(out); 
  SCAN->getIO()->openOutput(file,out); 
}
void closeOutput(int out)            
{ 
  if(out<0 || out>=MAXOUT) return;
  SCAN->getIO()->closeOutput(out); 
}
void cd()                   
{ 
  SCAN->cd();
}   
void addHist(char* file)    
{ 
  SCAN->addHist(file);
} 
void saveHist(char* file)   
{ 
  SCAN->saveHist(file);
}   
void hac(char* file)        
{ 
  SCAN->loadHist(file);
}  
void loadL2(char* file)     
{ 
  SCAN->loadL2(file);
}  
void unloadL2()     
{ 
  SCAN->unloadL2();
}  
void zero()                 
{ 
  SCAN->zero();
}
void zero(char* name)                 
{ 
  SCAN->zero(name);
}
int go(int N)              
{ 
  return SCAN->go(N); 
}
int skip(int N)              
{ 
  return SCAN->getIO()->skipEvents(N); 
}
void tools()                
{ 
  SCAN->pelTools(); 
}
void help()                 
{ 
  openHelp();
}
void stat()                 
{ 
  SCAN->stat();
}
void setNPar(int N)         
{ 
  SCAN->setNPar(N);
}
void saveOnlyNewPar(bool a)         
{ 
  SCAN->outputSaveModeGUI(a);
}
void smearing(bool a)
{
  SCAN->smearingModeGUI(a);
}
ScanRootGui* getScan() 
{
  return SCAN;
}










